@@ -4,6 +4,8 @@ regression <- function(d,model=1,type='york'){
     else if (model==3) out <- model3regression(d,type=type)
     else stop('invalid regression model')
     out$model <- model
+    out$d <- d
+    out$n <- nrow(d)
     out
 }
 
@@ -48,17 +50,15 @@ model2regression <- function(d,type='york'){
 model3regression <- function(d,type='york'){
     out <- list()
     if (identical(type,'york')){
-        init <- york(d)
-        out$w <- stats::optimize(york_disp_misfit,
-                                 interval=c(0,init$mswd),
-                                 d=d)$minimum
+        out$w <- stats::optimize(LL.york,
+                                 interval=c(0,stats::sd(d[,'Y'])),
+                                 d=d,maximum=TRUE)$maximum
         dd <- augment_york_errors(d,out$w)
         out <- c(out,york(dd))
     } else if (identical(type,'titterington')){
-        init <- titterington(d)
-        out$w <- stats::optimize(titterington_disp_misfit,
-                                 interval=c(0,init$mswd),
-                                 d=d)$minimum
+        out$w <- stats::optimize(LL.titterington,
+                                 interval=c(0,stats::sd(d[,'Y'])),
+                                 d=d,maximum=TRUE)$maximum
         dd <- augment_titterington_errors(d,out$w)
         out <- c(out,titterington(dd))
     } else {
@@ -67,13 +67,51 @@ model3regression <- function(d,type='york'){
     out
 }
 
-york_disp_misfit <- function(w2,d){
-    dd <- augment_york_errors(d,w2)
-    abs(york(dd)$mswd - 1)
+LL.isochron <- function(w,d,type='york'){
+    if (identical(type,'york'))
+        out <- LL.york(w,d)
+    else
+        out <- LL.titterington(w,d)
+    out
 }
-titterington_disp_misfit <- function(w2,d){
-    dd <- augment_titterington_errors(d,w2)
-    abs(titterington(dd)$mswd - 1)
+LL.york <- function(w,d){
+    out <- 0
+    D <- augment_york_errors(d,w)
+    X <- matrix(0,1,2)
+    fit <- york(D)
+    P <- get.york.xy(D,fit$a[1],fit$b[1])
+    for (i in 1:nrow(D)){
+        E <- cor2cov2(D[i,'sX'],D[i,'sY'],D[i,'rXY'])
+        X[1,1] <- D[i,'X']-P[i,1]
+        X[1,2] <- D[i,'Y']-P[i,2]
+        out <- out - 0.5*determinant(E,logarithm=TRUE)$modulus
+                   - 0.5 * X %*% solve(E) %*% t(X)
+    }
+    out
+}
+LL.titterington <- function(w,d){
+    out <- 0
+    D <- augment_titterington_errors(d,w)
+    fit <- titterington(D)
+    dat <- matrix2covlist(D)
+    X <- matrix(0,1,3)
+    ns <- nrow(D)
+    for (i in 1:ns){
+        XYZ <- dat$XYZ[[i]]
+        O <- dat$omega[[i]]
+        E <- solve(O)
+        a <- fit$par[1]
+        b <- fit$par[2]
+        A <- fit$par[3]
+        B <- fit$par[4]
+        abg <- alpha.beta.gamma(a,b,A,B,XYZ,O)
+        X[1,1] <- -abg[2]/abg[1]
+        X[1,2] <- XYZ[2] - a - b*XYZ[1]
+        X[1,3] <- XYZ[3] - A - B*XYZ[1]
+        out <- out - 0.5*determinant(E,logarithm=TRUE)$modulus
+                   - 0.5 * X %*% O %*% t(X)
+    }
+    out
 }
 
 augment_york_errors <- function(d,w){
@@ -84,8 +122,8 @@ augment_york_errors <- function(d,w){
 }
 augment_titterington_errors <- function(d,w){
     out <- d
-    out[,'sZ'] <- sqrt(d[,'sZ']^2 + w^2)
-    out[,'rXZ'] <- d[,'rXZ']*d[,'sZ']/out[,'sZ']
-    out[,'rYZ'] <- d[,'rYZ']*d[,'sZ']/out[,'sZ']
+    out[,'sY'] <- sqrt(d[,'sY']^2 + w^2)
+    out[,'rXY'] <- d[,'rXY']*d[,'sY']/out[,'sY']
+    out[,'rYZ'] <- d[,'rYZ']*d[,'sY']/out[,'sY']
     out
 }
