@@ -105,6 +105,10 @@ weightedmean <- function(x,...){ UseMethod("weightedmean",x) }
 #' @param plot logical flag indicating whether the function should
 #'     produce graphical output or return numerical values to the
 #'     user.
+#' @param from minimum y-axis limit. Setting \code{from=NA} scales the
+#'     plot automatically.
+#' @param to maximum y-axis limit. Setting \code{to=NA} scales the
+#'     plot automatically.
 #' @param rect.col the fill colour of the rectangles used to show the
 #'     measurements or age estimates.
 #' @param outlier.col if \code{detect.outliers=TRUE}, the outliers are
@@ -112,14 +116,15 @@ weightedmean <- function(x,...){ UseMethod("weightedmean",x) }
 #' @param sigdig the number of significant digits of the numerical
 #'     values reported in the title of the graphical output.
 #' @param alpha the confidence limits of the error bars/rectangles.
+#' @param ranked plot the aliquots in order of increasing age?
 #' @importFrom grDevices rgb
 #' @rdname weightedmean
 #' @export
-weightedmean.default <- function(x,random.effects=TRUE,
-                                 detect.outliers=TRUE, plot=TRUE,
+weightedmean.default <- function(x,from=NA,to=NA,random.effects=TRUE,
+                                 detect.outliers=TRUE,plot=TRUE,
                                  rect.col=rgb(0,1,0,0.5),
-                                 outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                                 alpha=0.05,...){
+                                 outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                                 alpha=0.05,ranked=FALSE,...){
     X <- x[,1]
     sX <- x[,2]
     valid <- !is.na(X) & !is.na(sX)
@@ -137,9 +142,9 @@ weightedmean.default <- function(x,random.effects=TRUE,
     out <- get.weightedmean(X,sX,random.effects=random.effects,
                             valid=valid,alpha=alpha)
     if (plot){
-        plot_weightedmean(X,sX,out,rect.col=rect.col,
-                          outlier.col=outlier.col,sigdig=sigdig,
-                          alpha=alpha,...)
+        plot_weightedmean(X,sX,fit=out,from=from,to=to,
+                          rect.col=rect.col,outlier.col=outlier.col,
+                          sigdig=sigdig,alpha=alpha,ranked=ranked,...)
     }
     invisible(out)
 }
@@ -185,141 +190,177 @@ weightedmean.default <- function(x,random.effects=TRUE,
 #' @export
 weightedmean.UPb <- function(x,random.effects=TRUE,
                              detect.outliers=TRUE,plot=TRUE,
-                             rect.col=rgb(0,1,0,0.5),
-                             outlier.col=rgb(0,1,1,0.5), sigdig=2,
+                             from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                             outlier.col=rgb(0,1,1,0.5),sigdig=2,
                              type=4,cutoff.76=1100,
                              cutoff.disc=c(-15,5),alpha=0.05,
-                             exterr=TRUE,common.Pb=0,...){
+                             exterr=TRUE,ranked=FALSE,common.Pb=0,...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
         X <- x
     weightedmean_helper(X,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        type=type,cutoff.76=cutoff.76,
-                        cutoff.disc=cutoff.disc,sigdig=sigdig,
-                        alpha=alpha,exterr=exterr,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,type=type,
+                        cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
+                        sigdig=sigdig,alpha=alpha,exterr=exterr,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.PbPb <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,common.Pb=1,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,common.Pb=1,
+                              ranked=FALSE,...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
         X <- x
     weightedmean_helper(X,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,
+                        units='Ma',ranked=ranked,...)
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
 #'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
 #'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
-#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
-#'     uses the default values stored in
-#'     \code{settings('iratio',...)}. When applied to data of class
-#'     \code{ThU}, setting \code{i2i} to \code{TRUE} applies a
-#'     detrital Th-correction.
+#'     \eqn{^{187}}Os/\eqn{^{188}}Os, \eqn{^{230}}Th/\eqn{^{232}}Th or
+#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
+#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
+#'     stored in \code{settings('iratio',...)}.
+#' @param detritus detrital \eqn{^{230}}Th correction (only applicable
+#'     when \code{x$format == 1} or \code{2}.
+#'
+#' \code{0}: no correction
+#'
+#' \code{1}: project the data along an isochron fit
+#'
+#' \code{2}: correct the data using an assumed initial
+#' \eqn{^{230}}Th/\eqn{^{232}}Th-ratio for the detritus.
+#'
+#' \code{3}: correct the data using the measured present day
+#' \eqn{^{230}}Th/\eqn{^{238}}U, \eqn{^{232}}Th/\eqn{^{238}}U and
+#' \eqn{^{234}}U/\eqn{^{238}}U-ratios in the detritus.
+#'
+#' @param Th02 2-element vector with the assumed initial
+#'     \eqn{^{230}}Th/\eqn{^{232}}Th-ratio of the detritus and its
+#'     standard error. Only used if \code{detritus==2}
+#' @param Th02U48 9-element vector with the measured composition of
+#'     the detritus, containing \code{X=0/8}, \code{sX}, \code{Y=2/8},
+#'     \code{sY}, \code{Z=4/8}, \code{sZ}, \code{rXY}, \code{rXZ},
+#'     \code{rYZ}. Only used if \code{isochron==FALSE} and
+#'     \code{detritus==3}
 #' @rdname weightedmean
 #' @export
 weightedmean.ThU <- function(x,random.effects=TRUE,
                              detect.outliers=TRUE,plot=TRUE,
-                             rect.col=rgb(0,1,0,0.5),
-                             outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                             alpha=0.05,i2i=TRUE,...){
+                             from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                             outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                             alpha=0.05,ranked=FALSE,i2i=TRUE,
+                             detritus=0,Th02=c(0,0),
+                             Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,i2i=i2i,units='ka',
-                        ...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,alpha=alpha,
+                        ranked=ranked,i2i=i2i,units='ka',detritus=detritus,
+                        Th02=Th02,Th02U48=Th02U48, ...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.ArAr <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,i2i=FALSE,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,ranked=FALSE,
+                              i2i=FALSE,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        i2i=i2i,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,i2i=i2i,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.ReOs <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,i2i=TRUE,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,ranked=FALSE,
+                              i2i=TRUE,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        i2i=i2i,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,i2i=i2i,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.SmNd <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,i2i=TRUE,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,ranked=FALSE,
+                              i2i=TRUE,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        i2i=i2i,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,i2i=i2i,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.RbSr <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,i2i=TRUE,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,
+                              i2i=TRUE,ranked=FALSE,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        i2i=i2i,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,i2i=i2i,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.LuHf <- function(x,random.effects=TRUE,
                               detect.outliers=TRUE,plot=TRUE,
-                              rect.col=rgb(0,1,0,0.5),
-                              outlier.col=rgb(0,1,1,0.5), sigdig=2,
-                              alpha=0.05,exterr=TRUE,i2i=TRUE,...){
+                              from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
+                              outlier.col=rgb(0,1,1,0.5),sigdig=2,
+                              alpha=0.05,exterr=TRUE,i2i=TRUE,
+                              ranked=FALSE,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
-                        rect.col=rect.col,outlier.col=outlier.col,
-                        sigdig=sigdig,alpha=alpha,exterr=exterr,
-                        i2i=i2i,units='Ma',...)
+                        from=from,to=to,rect.col=rect.col,
+                        outlier.col=outlier.col,sigdig=sigdig,
+                        alpha=alpha,exterr=exterr,i2i=i2i,
+                        units='Ma',ranked=ranked,...)
 }
 #' @rdname weightedmean
 #' @export
 weightedmean.UThHe <- function(x,random.effects=TRUE,
                                detect.outliers=TRUE,plot=TRUE,
-                               rect.col=rgb(0,1,0,0.5),
+                               from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
                                outlier.col=rgb(0,1,1,0.5),sigdig=2,
-                               alpha=0.05,...){
+                               alpha=0.05,ranked=FALSE,...){
     tt <- UThHe.age(x)
     fit <- weightedmean.default(tt,detect.outliers=detect.outliers,
                                 alpha=alpha,plot=FALSE,...)
     if (plot){
-        plot_weightedmean(tt[,1],tt[,2],fit,rect.col=rect.col,
-                          outlier.col=outlier.col,sigdig=sigdig,
-                          alpha=alpha,units='Ma')
+        plot_weightedmean(tt[,1],tt[,2],fit=fit,from=from,to=to,
+                          rect.col=rect.col,outlier.col=outlier.col,
+                          sigdig=sigdig,alpha=alpha,units='Ma',ranked=ranked)
     }
     invisible(fit)
 }
@@ -327,10 +368,10 @@ weightedmean.UThHe <- function(x,random.effects=TRUE,
 #' @export
 weightedmean.fissiontracks <- function(x,random.effects=TRUE,
                                        detect.outliers=TRUE,plot=TRUE,
-                                       rect.col=rgb(0,1,0,0.5),
+                                       from=NA,to=NA,rect.col=rgb(0,1,0,0.5),
                                        outlier.col=rgb(0,1,1,0.5),
                                        sigdig=2,alpha=0.05,
-                                       exterr=TRUE,...){
+                                       exterr=TRUE,ranked=FALSE,...){
     tt <- fissiontrack.age(x,exterr=FALSE)
     # calculated weighted mean age ignoring zeta and rhoD uncertainties
     fit <- weightedmean.default(tt,detect.outliers=detect.outliers,
@@ -355,27 +396,29 @@ weightedmean.fissiontracks <- function(x,random.effects=TRUE,
         out$mean['ci[x]'] <- nfact(alpha)*out$mean['s[x]']
     }
     if (plot){
-        plot_weightedmean(tt[,1],tt[,2],out,rect.col=rect.col,
-                          outlier.col=outlier.col,sigdig=sigdig,
-                          alpha=alpha,units='Ma')
+        plot_weightedmean(tt[,1],tt[,2],fit=out,from=from,to=to,
+                          rect.col=rect.col,outlier.col=outlier.col,
+                          sigdig=sigdig,alpha=alpha,units='Ma',ranked=ranked)
     }
     invisible(out)
 }
-weightedmean_helper <- function(x,random.effects=TRUE,
-                                detect.outliers=TRUE,plot=TRUE,
-                                rect.col=grDevices::rgb(0,1,0,0.5),
-                                type=4,cutoff.76=1100,
-                                cutoff.disc=c(-15,5),
+weightedmean_helper <- function(x,random.effects=TRUE,detect.outliers=TRUE,
+                                plot=TRUE,from=NA,to=NA,
+                                rect.col=grDevices::rgb(0,1,0,0.5),type=4,
+                                cutoff.76=1100,cutoff.disc=c(-15,5),
                                 outlier.col=grDevices::rgb(0,1,1,0.5),
                                 sigdig=2,alpha=0.05,exterr=TRUE,
-                                i2i=FALSE,common.Pb=1,units='',...){
+                                ranked=FALSE,i2i=FALSE,common.Pb=1,
+                                units='',detritus=0,Th02=c(0,0),
+                                Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
     if (hasClass(x,'UPb')){
         tt <- filter.UPb.ages(x,type=type,cutoff.76=cutoff.76,
                               cutoff.disc=cutoff.disc,exterr=FALSE)
     } else if (hasClass(x,'PbPb')){
         tt <- PbPb.age(x,exterr=FALSE)
     } else if (hasClass(x,'ThU')){
-        tt <- ThU.age(x,exterr=FALSE,i2i=i2i)
+        tt <- ThU.age(x,exterr=FALSE,i2i=i2i,detritus=detritus,
+                      Th02=Th02,Th02U48=Th02U48)
         exterr <- FALSE
     } else if (hasClass(x,'ArAr')){
         tt <- ArAr.age(x,jcu=FALSE,exterr=FALSE,i2i=i2i)
@@ -399,9 +442,9 @@ weightedmean_helper <- function(x,random.effects=TRUE,
         out$mean['ci[x]'] <- nfact(alpha)*out$mean['s[x]']
     }
     if (plot){
-        plot_weightedmean(tt[,1],tt[,2],out,rect.col=rect.col,
-                          outlier.col=outlier.col,sigdig=sigdig,
-                          alpha=alpha,units=units)
+        plot_weightedmean(tt[,1],tt[,2],from=from,to=to,fit=out,
+                          rect.col=rect.col,outlier.col=outlier.col,
+                          sigdig=sigdig,alpha=alpha,units=units,ranked=ranked)
     }
     invisible(out)
 }
@@ -511,15 +554,27 @@ wtdmean.title <- function(fit,sigdig=2,units=''){
     graphics::mtext(line2,line=line2line)
 }
 
-plot_weightedmean <- function(X,sX,fit,
+plot_weightedmean <- function(X,sX,fit,from=NA,to=NA,
                               rect.col=grDevices::rgb(0,1,0,0.5),
                               outlier.col=grDevices::rgb(0,1,1,0.5),
-                              sigdig=2,alpha=0.05,units=''){
-    ns <- length(X)
+                              sigdig=2,alpha=0.05,units='',ranked=FALSE){
+    if (ranked){
+        i <- order(X)
+        x <- X[i]
+        sx <- sX[i]
+        valid <- fit$valid[i]
+    } else {
+        x <- X
+        sx <- sX
+        valid <- fit$valid
+    }
+    ns <- length(x)
     fact <- nfact(alpha)
-    minX <- min(c(X-fact*sX,X-fact*fit$disp['w']),na.rm=TRUE)
-    maxX <- max(c(X+fact*sX,X+fact*fit$disp['w']),na.rm=TRUE)
-    graphics::plot(c(0,ns+1),c(minX,maxX),type='n',
+    if (is.na(from)) minx <- min(c(x-fact*sx,x-fact*fit$disp['w']),na.rm=TRUE)
+    else minx <- from
+    if (is.na(to)) maxx <- max(c(x+fact*sx,x+fact*fit$disp['w']),na.rm=TRUE)
+    else maxx <- to
+    graphics::plot(c(0,ns+1),c(minx,maxx),type='n',
                    axes=FALSE,xlab='N',ylab='')
     graphics::polygon(fit$plotpar$rect,col='gray80',border=NA)
     graphics::lines(fit$plotpar$mean)
@@ -530,10 +585,10 @@ plot_weightedmean <- function(X,sX,fit,
     graphics::axis(side=1,at=1:ns)
     graphics::axis(side=2)
     for (i in 1:ns){
-        if (fit$valid[i]) col <- rect.col
+        if (valid[i]) col <- rect.col
         else col <- outlier.col
-        graphics::rect(xleft=i-0.4,ybottom=X[i]-fact*sX[i],
-                       xright=i+0.4,ytop=X[i]+fact*sX[i],col=col)
+        graphics::rect(xleft=i-0.4,ybottom=x[i]-fact*sx[i],
+                       xright=i+0.4,ytop=x[i]+fact*sx[i],col=col)
     }
     graphics::title(wtdmean.title(fit,sigdig=sigdig,units=units))
 }
@@ -547,11 +602,13 @@ chauvenet <- function(X,sX,valid,random.effects=TRUE){
                             valid=valid)
     mu <- fit$mean[1]
     if (random.effects) sigma <- sqrt(fit$disp[1]^2+sX^2)
-    else sigma <- sqrt(fit$mswd)*sX
+    else sigma <- sqrt(fit$mswd*fit$mean[2]^2 + sX^2)
     prob <- 2*(1-stats::pnorm(abs(X-mu),sd=sigma))
-    minp <- min(prob[valid])
-    imin <- which.min(sX/abs(X-mu))
-    ns <- length(valid[valid])
+    iprob <- order(prob)
+    npruned <- length(which(!valid))
+    imin <- iprob[npruned+1]
+    minp <- prob[imin]
+    ns <- length(which(valid))
     if (ns*minp < 0.5) valid[imin] <- FALSE # remove outlier
     valid
 }
